// python wrapper for vtkDistributedDataFilter
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkInformationVector.h"
#include "vtkDistributedDataFilter.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkDistributedDataFilter(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkDistributedDataFilter_ClassNew(); }

#ifndef DECLARED_PyvtkDataObjectAlgorithm_ClassNew
extern "C" { PyObject *PyvtkDataObjectAlgorithm_ClassNew(); }
#define DECLARED_PyvtkDataObjectAlgorithm_ClassNew
#endif

static const char *PyvtkDistributedDataFilter_Doc =
  "vtkDistributedDataFilter - Distribute data among processors\n\n"
  "Superclass: vtkDataObjectAlgorithm\n\n"
  "This filter redistributes data among processors in a parallel\n"
  "application into spatially contiguous vtkUnstructuredGrids. The\n"
  "execution model anticipated is that all processes read in part of a\n"
  "large vtkDataSet. Each process sets the input of filter to be that\n"
  "DataSet. When executed, this filter builds in parallel a k-d tree,\n"
  "decomposing the space occupied by the distributed DataSet into\n"
  "spatial regions.  It assigns each spatial region to a processor.  The\n"
  "data is then redistributed and the output is a single\n"
  "vtkUnstructuredGrid containing the cells in the process' assigned\n"
  "regions.\n\n"
  "This filter is sometimes called \"D3\" for \"distributed data\n"
  "decomposition\".\n\n"
  "Enhancement: You can set the k-d tree decomposition, rather than have\n"
  "D3 compute it.  This allows you to divide a dataset using the\n"
  "decomposition computed for another dataset.  Obtain a description of\n"
  "the k-d tree cuts this way:\n\n"
  "{cpp}\n"
  "   vtkBSPCuts *cuts = D3Object1->GetCuts()\n\n"
  "And set it this way:\n\n"
  "{cpp}\n"
  "    D3Object2->SetCuts(cuts)\n\n"
  "It is desirable to have a field array of global node IDs for two\n"
  "reasons:\n\n"
  "1. When merging together sub grids that were distributed across\n"
  "   processors, global node IDs can be used to remove duplicate points\n"
  "and significantly reduce the size of the resulting output grid.  If\n"
  "   no such array is available, D3 will use a tolerance to merge\n"
  "   points, which is much slower.\n\n"
  "2. If ghost cells have been requested, D3 requires a global node ID\n"
  "   array in order to request and transfer ghost cells in parallel\n"
  "   among the processors.  If there is no global node ID array, D3\n"
  "   will in parallel create a global node ID array, and the time to do\n"
  "this can be significant.\n\n"
  "D3 uses `vtkPointData::GetGlobalIds` to access global node ids from\n"
  "the input. If none is found, and ghost cells have been requested, D3\n"
  "will create a temporary global node ID array before acquiring ghost\n"
  "cells.\n\n"
  "It is also desirable to have global element IDs\n"
  "(vtkCellData::GetGlobalIds). However, if they don't exist D3 can\n"
  "create them relatively quickly.\n\n"
  "@warning\n"
  "The Execute() method must be called by all processes in the parallel\n"
  "application, or it will hang.  If you are not certain that your\n"
  "pipeline will execute identically on all processors, you may want to\n"
  "use this filter in an explicit execution mode.\n\n"
  "@sa\n"
  "vtkKdTree vtkPKdTree vtkBSPCuts\n\n";

static PyTypeObject PyvtkDistributedDataFilter_BoundaryModes_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkFiltersParallelMPIPython.vtkDistributedDataFilter.BoundaryModes", // tp_name
  sizeof(PyIntObject), // tp_basicsize
  0, // tp_itemsize
  nullptr, // tp_dealloc
  nullptr, // tp_print
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  nullptr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  nullptr, // tp_str
  nullptr, // tp_getattro
  nullptr, // tp_setattro
  nullptr, // tp_as_buffer
  Py_TPFLAGS_DEFAULT, // tp_flags
  nullptr, // tp_doc
  nullptr, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  0, // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  nullptr, // tp_getset
  &PyInt_Type, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  0, // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  nullptr, // tp_new
  PyObject_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

PyObject *PyvtkDistributedDataFilter_BoundaryModes_FromEnum(int val)
{
#ifdef VTK_PY3K
  PyObject *args = Py_BuildValue("(i)", val);
  PyObject *obj = PyLong_Type.tp_new(&PyvtkDistributedDataFilter_BoundaryModes_Type, args, nullptr);
  Py_DECREF(args);
  return obj;
#else
  PyIntObject *self = PyObject_New(PyIntObject,
    &PyvtkDistributedDataFilter_BoundaryModes_Type);
  self->ob_ival = val;
  return (PyObject *)self;
#endif
}


static PyObject *
PyvtkDistributedDataFilter_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkDistributedDataFilter::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkDistributedDataFilter::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkDistributedDataFilter *tempr = vtkDistributedDataFilter::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDistributedDataFilter *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkDistributedDataFilter::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  vtkMultiProcessController *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMultiProcessController"))
  {
    if (ap.IsBound())
    {
      op->SetController(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetController(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMultiProcessController *tempr = (ap.IsBound() ?
      op->GetController() :
      op->vtkDistributedDataFilter::GetController());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetKdtree(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetKdtree");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkPKdTree *tempr = (ap.IsBound() ?
      op->GetKdtree() :
      op->vtkDistributedDataFilter::GetKdtree());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_RetainKdtreeOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RetainKdtreeOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->RetainKdtreeOn();
    }
    else
    {
      op->vtkDistributedDataFilter::RetainKdtreeOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_RetainKdtreeOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RetainKdtreeOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->RetainKdtreeOff();
    }
    else
    {
      op->vtkDistributedDataFilter::RetainKdtreeOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetRetainKdtree(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRetainKdtree");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetRetainKdtree() :
      op->vtkDistributedDataFilter::GetRetainKdtree());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetRetainKdtree(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetRetainKdtree");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetRetainKdtree(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetRetainKdtree(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_IncludeAllIntersectingCellsOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IncludeAllIntersectingCellsOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->IncludeAllIntersectingCellsOn();
    }
    else
    {
      op->vtkDistributedDataFilter::IncludeAllIntersectingCellsOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_IncludeAllIntersectingCellsOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IncludeAllIntersectingCellsOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->IncludeAllIntersectingCellsOff();
    }
    else
    {
      op->vtkDistributedDataFilter::IncludeAllIntersectingCellsOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetIncludeAllIntersectingCells(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetIncludeAllIntersectingCells");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetIncludeAllIntersectingCells() :
      op->vtkDistributedDataFilter::GetIncludeAllIntersectingCells());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetIncludeAllIntersectingCells(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetIncludeAllIntersectingCells");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetIncludeAllIntersectingCells(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetIncludeAllIntersectingCells(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_ClipCellsOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ClipCellsOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ClipCellsOn();
    }
    else
    {
      op->vtkDistributedDataFilter::ClipCellsOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_ClipCellsOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ClipCellsOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ClipCellsOff();
    }
    else
    {
      op->vtkDistributedDataFilter::ClipCellsOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetClipCells(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetClipCells");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetClipCells() :
      op->vtkDistributedDataFilter::GetClipCells());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetClipCells(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetClipCells");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetClipCells(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetClipCells(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetBoundaryMode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetBoundaryMode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetBoundaryMode(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetBoundaryMode(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetBoundaryModeToAssignToOneRegion(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetBoundaryModeToAssignToOneRegion");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->SetBoundaryModeToAssignToOneRegion();
    }
    else
    {
      op->vtkDistributedDataFilter::SetBoundaryModeToAssignToOneRegion();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetBoundaryModeToAssignToAllIntersectingRegions(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetBoundaryModeToAssignToAllIntersectingRegions");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->SetBoundaryModeToAssignToAllIntersectingRegions();
    }
    else
    {
      op->vtkDistributedDataFilter::SetBoundaryModeToAssignToAllIntersectingRegions();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetBoundaryModeToSplitBoundaryCells(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetBoundaryModeToSplitBoundaryCells");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->SetBoundaryModeToSplitBoundaryCells();
    }
    else
    {
      op->vtkDistributedDataFilter::SetBoundaryModeToSplitBoundaryCells();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetBoundaryMode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetBoundaryMode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetBoundaryMode() :
      op->vtkDistributedDataFilter::GetBoundaryMode());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_UseMinimalMemoryOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UseMinimalMemoryOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UseMinimalMemoryOn();
    }
    else
    {
      op->vtkDistributedDataFilter::UseMinimalMemoryOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_UseMinimalMemoryOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UseMinimalMemoryOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UseMinimalMemoryOff();
    }
    else
    {
      op->vtkDistributedDataFilter::UseMinimalMemoryOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetUseMinimalMemory(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetUseMinimalMemory");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetUseMinimalMemory() :
      op->vtkDistributedDataFilter::GetUseMinimalMemory());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetUseMinimalMemory(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetUseMinimalMemory");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetUseMinimalMemory(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetUseMinimalMemory(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetMinimumGhostLevel(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetMinimumGhostLevel");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetMinimumGhostLevel() :
      op->vtkDistributedDataFilter::GetMinimumGhostLevel());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetMinimumGhostLevel(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetMinimumGhostLevel");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetMinimumGhostLevel(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetMinimumGhostLevel(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_TimingOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "TimingOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->TimingOn();
    }
    else
    {
      op->vtkDistributedDataFilter::TimingOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_TimingOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "TimingOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->TimingOff();
    }
    else
    {
      op->vtkDistributedDataFilter::TimingOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetTiming(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTiming");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetTiming(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetTiming(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetTiming(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTiming");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetTiming() :
      op->vtkDistributedDataFilter::GetTiming());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_GetCuts(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCuts");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkBSPCuts *tempr = (ap.IsBound() ?
      op->GetCuts() :
      op->vtkDistributedDataFilter::GetCuts());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetCuts(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCuts");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  vtkBSPCuts *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkBSPCuts"))
  {
    if (ap.IsBound())
    {
      op->SetCuts(temp0);
    }
    else
    {
      op->vtkDistributedDataFilter::SetCuts(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDistributedDataFilter_SetUserRegionAssignments(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetUserRegionAssignments");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkDistributedDataFilter *op = static_cast<vtkDistributedDataFilter *>(vp);

  size_t size0 = ap.GetArgSize(0);
  vtkPythonArgs::Array<int> store0(size0);
  int *temp0 = store0.Data();
  int temp1;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetArray(temp0, size0) &&
      ap.GetValue(temp1))
  {
    if (ap.IsBound())
    {
      op->SetUserRegionAssignments(temp0, temp1);
    }
    else
    {
      op->vtkDistributedDataFilter::SetUserRegionAssignments(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkDistributedDataFilter_Methods[] = {
  {"IsTypeOf", PyvtkDistributedDataFilter_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkDistributedDataFilter_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkDistributedDataFilter_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkDistributedDataFilter\nC++: static vtkDistributedDataFilter *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkDistributedDataFilter_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkDistributedDataFilter\nC++: vtkDistributedDataFilter *NewInstance()\n\n"},
  {"SetController", PyvtkDistributedDataFilter_SetController, METH_VARARGS,
   "V.SetController(vtkMultiProcessController)\nC++: void SetController(vtkMultiProcessController *c)\n\nSet/Get the communicator object\n"},
  {"GetController", PyvtkDistributedDataFilter_GetController, METH_VARARGS,
   "V.GetController() -> vtkMultiProcessController\nC++: virtual vtkMultiProcessController *GetController()\n\nSet/Get the communicator object\n"},
  {"GetKdtree", PyvtkDistributedDataFilter_GetKdtree, METH_VARARGS,
   "V.GetKdtree() -> vtkPKdTree\nC++: vtkPKdTree *GetKdtree()\n\nGet a pointer to the parallel k-d tree object.  Required for\nchanging default behavior for region assignment, changing default\ndepth of tree, or other tree building default parameters.  See\nvtkPKdTree and vtkKdTree for more information about these\noptions. NOTE: Changing the tree returned by this method does NOT\nchange the d3 filter. Make sure to call Modified() on the d3\nobject if you want it to re-execute.\n"},
  {"RetainKdtreeOn", PyvtkDistributedDataFilter_RetainKdtreeOn, METH_VARARGS,
   "V.RetainKdtreeOn()\nC++: virtual void RetainKdtreeOn()\n\nWhen this filter executes, it creates a vtkPKdTree (K-d tree)\ndata structure in parallel which divides the total distributed\ndata set into spatial regions.  The K-d tree object also creates\ntables describing which processes have data for which regions. \nOnly then does this filter redistribute the data according to the\nregion assignment scheme.  By default, the K-d tree structure and\nit's associated tables are deleted after the filter executes.  If\nyou anticipate changing only the region assignment scheme (input\nis unchanged) and explicitly re-executing, then RetainKdTreeOn,\nand the K-d tree structure and tables will be saved.  Then, when\nyou re-execute, this filter will skip the k-d tree build phase\nand go straight to redistributing the data according to region\nassignment.  See vtkPKdTree for more information about region\nassignment.\n"},
  {"RetainKdtreeOff", PyvtkDistributedDataFilter_RetainKdtreeOff, METH_VARARGS,
   "V.RetainKdtreeOff()\nC++: virtual void RetainKdtreeOff()\n\n"},
  {"GetRetainKdtree", PyvtkDistributedDataFilter_GetRetainKdtree, METH_VARARGS,
   "V.GetRetainKdtree() -> int\nC++: virtual int GetRetainKdtree()\n\n"},
  {"SetRetainKdtree", PyvtkDistributedDataFilter_SetRetainKdtree, METH_VARARGS,
   "V.SetRetainKdtree(int)\nC++: virtual void SetRetainKdtree(int _arg)\n\n"},
  {"IncludeAllIntersectingCellsOn", PyvtkDistributedDataFilter_IncludeAllIntersectingCellsOn, METH_VARARGS,
   "V.IncludeAllIntersectingCellsOn()\nC++: virtual void IncludeAllIntersectingCellsOn()\n\nEach cell in the data set is associated with one of the spatial\nregions of the k-d tree decomposition.  In particular, the cell\nbelongs to the region that it's centroid lies in. When the new\nvtkUnstructuredGrid is created, by default it is composed of the\ncells associated with the region(s) assigned to this process.  If\nyou also want it to contain cells that intersect these regions,\nbut have their centroid elsewhere, then set this variable on.  By\ndefault it is off.\n"},
  {"IncludeAllIntersectingCellsOff", PyvtkDistributedDataFilter_IncludeAllIntersectingCellsOff, METH_VARARGS,
   "V.IncludeAllIntersectingCellsOff()\nC++: virtual void IncludeAllIntersectingCellsOff()\n\n"},
  {"GetIncludeAllIntersectingCells", PyvtkDistributedDataFilter_GetIncludeAllIntersectingCells, METH_VARARGS,
   "V.GetIncludeAllIntersectingCells() -> int\nC++: virtual int GetIncludeAllIntersectingCells()\n\n"},
  {"SetIncludeAllIntersectingCells", PyvtkDistributedDataFilter_SetIncludeAllIntersectingCells, METH_VARARGS,
   "V.SetIncludeAllIntersectingCells(int)\nC++: virtual void SetIncludeAllIntersectingCells(int _arg)\n\n"},
  {"ClipCellsOn", PyvtkDistributedDataFilter_ClipCellsOn, METH_VARARGS,
   "V.ClipCellsOn()\nC++: virtual void ClipCellsOn()\n\nSet this variable if you want the cells of the output\nvtkUnstructuredGrid to be clipped to the spatial region\nboundaries.  By default this is off.\n"},
  {"ClipCellsOff", PyvtkDistributedDataFilter_ClipCellsOff, METH_VARARGS,
   "V.ClipCellsOff()\nC++: virtual void ClipCellsOff()\n\n"},
  {"GetClipCells", PyvtkDistributedDataFilter_GetClipCells, METH_VARARGS,
   "V.GetClipCells() -> int\nC++: virtual int GetClipCells()\n\n"},
  {"SetClipCells", PyvtkDistributedDataFilter_SetClipCells, METH_VARARGS,
   "V.SetClipCells(int)\nC++: virtual void SetClipCells(int _arg)\n\n"},
  {"SetBoundaryMode", PyvtkDistributedDataFilter_SetBoundaryMode, METH_VARARGS,
   "V.SetBoundaryMode(int)\nC++: void SetBoundaryMode(int mode)\n\nHandling of ClipCells and IncludeAllIntersectingCells.\n"},
  {"SetBoundaryModeToAssignToOneRegion", PyvtkDistributedDataFilter_SetBoundaryModeToAssignToOneRegion, METH_VARARGS,
   "V.SetBoundaryModeToAssignToOneRegion()\nC++: void SetBoundaryModeToAssignToOneRegion()\n\nHandling of ClipCells and IncludeAllIntersectingCells.\n"},
  {"SetBoundaryModeToAssignToAllIntersectingRegions", PyvtkDistributedDataFilter_SetBoundaryModeToAssignToAllIntersectingRegions, METH_VARARGS,
   "V.SetBoundaryModeToAssignToAllIntersectingRegions()\nC++: void SetBoundaryModeToAssignToAllIntersectingRegions()\n\nHandling of ClipCells and IncludeAllIntersectingCells.\n"},
  {"SetBoundaryModeToSplitBoundaryCells", PyvtkDistributedDataFilter_SetBoundaryModeToSplitBoundaryCells, METH_VARARGS,
   "V.SetBoundaryModeToSplitBoundaryCells()\nC++: void SetBoundaryModeToSplitBoundaryCells()\n\nHandling of ClipCells and IncludeAllIntersectingCells.\n"},
  {"GetBoundaryMode", PyvtkDistributedDataFilter_GetBoundaryMode, METH_VARARGS,
   "V.GetBoundaryMode() -> int\nC++: int GetBoundaryMode()\n\nHandling of ClipCells and IncludeAllIntersectingCells.\n"},
  {"UseMinimalMemoryOn", PyvtkDistributedDataFilter_UseMinimalMemoryOn, METH_VARARGS,
   "V.UseMinimalMemoryOn()\nC++: virtual void UseMinimalMemoryOn()\n\nThis class does a great deal of all-to-all communication when\nexchanging portions of data sets and building new sub grids. By\ndefault it will do fast communication.  It can instead use\ncommunication routines that use the least possible amount of\nmemory, but these are slower.  Set this option ON to choose these\nlatter routines.\n"},
  {"UseMinimalMemoryOff", PyvtkDistributedDataFilter_UseMinimalMemoryOff, METH_VARARGS,
   "V.UseMinimalMemoryOff()\nC++: virtual void UseMinimalMemoryOff()\n\n"},
  {"GetUseMinimalMemory", PyvtkDistributedDataFilter_GetUseMinimalMemory, METH_VARARGS,
   "V.GetUseMinimalMemory() -> int\nC++: virtual int GetUseMinimalMemory()\n\n"},
  {"SetUseMinimalMemory", PyvtkDistributedDataFilter_SetUseMinimalMemory, METH_VARARGS,
   "V.SetUseMinimalMemory(int)\nC++: virtual void SetUseMinimalMemory(int _arg)\n\n"},
  {"GetMinimumGhostLevel", PyvtkDistributedDataFilter_GetMinimumGhostLevel, METH_VARARGS,
   "V.GetMinimumGhostLevel() -> int\nC++: virtual int GetMinimumGhostLevel()\n\nThe minimum number of ghost levels to add to each processor's\noutput. If the pipeline also requests ghost levels, the larger\nvalue will be used.\n"},
  {"SetMinimumGhostLevel", PyvtkDistributedDataFilter_SetMinimumGhostLevel, METH_VARARGS,
   "V.SetMinimumGhostLevel(int)\nC++: virtual void SetMinimumGhostLevel(int _arg)\n\n"},
  {"TimingOn", PyvtkDistributedDataFilter_TimingOn, METH_VARARGS,
   "V.TimingOn()\nC++: virtual void TimingOn()\n\nTurn on collection of timing data\n"},
  {"TimingOff", PyvtkDistributedDataFilter_TimingOff, METH_VARARGS,
   "V.TimingOff()\nC++: virtual void TimingOff()\n\n"},
  {"SetTiming", PyvtkDistributedDataFilter_SetTiming, METH_VARARGS,
   "V.SetTiming(int)\nC++: virtual void SetTiming(int _arg)\n\n"},
  {"GetTiming", PyvtkDistributedDataFilter_GetTiming, METH_VARARGS,
   "V.GetTiming() -> int\nC++: virtual int GetTiming()\n\n"},
  {"GetCuts", PyvtkDistributedDataFilter_GetCuts, METH_VARARGS,
   "V.GetCuts() -> vtkBSPCuts\nC++: vtkBSPCuts *GetCuts()\n\nYou can set the k-d tree decomposition, rather than have D3\ncompute it.  This allows you to divide a dataset using the\ndecomposition computed for another dataset.  Obtain a description\nof the k-d tree cuts this way:\n\n* vtkBSPCuts *cuts = D3Object1->GetCuts()\n\n* And set it this way:\n\n* D3Object2->SetCuts(cuts)\n"},
  {"SetCuts", PyvtkDistributedDataFilter_SetCuts, METH_VARARGS,
   "V.SetCuts(vtkBSPCuts)\nC++: void SetCuts(vtkBSPCuts *cuts)\n\n"},
  {"SetUserRegionAssignments", PyvtkDistributedDataFilter_SetUserRegionAssignments, METH_VARARGS,
   "V.SetUserRegionAssignments((int, ...), int)\nC++: void SetUserRegionAssignments(const int *map, int numRegions)\n\nvtkBSPCuts doesn't have information about process assignments for\nthe cuts. Typically D3 filter simply reassigns the processes for\neach cut. However, that may not always work, sometimes the\nprocesses have be pre-assigned and we want to preserve that\npartitioning. In that case, one sets the region assignments\nexplicitly. Look at vtkPKdTree::AssignRegions for details about\nthe arguments. Calling SetUserRegionAssignments(nullptr, 0) will\nrevert to default behavior i.e. letting the KdTree come up with\nthe assignments.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkDistributedDataFilter_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkFiltersParallelMPIPython.vtkDistributedDataFilter", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  nullptr, // tp_print
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkDistributedDataFilter_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkDistributedDataFilter_StaticNew()
{
  return vtkDistributedDataFilter::New();
}

PyObject *PyvtkDistributedDataFilter_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkDistributedDataFilter_Type, PyvtkDistributedDataFilter_Methods,
    "vtkDistributedDataFilter",
 &PyvtkDistributedDataFilter_StaticNew);

  PyTypeObject *pytype = &PyvtkDistributedDataFilter_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkDataObjectAlgorithm_ClassNew();

  PyObject *d = pytype->tp_dict;
  PyObject *o;

  PyType_Ready(&PyvtkDistributedDataFilter_BoundaryModes_Type);
  PyvtkDistributedDataFilter_BoundaryModes_Type.tp_new = nullptr;
  vtkPythonUtil::AddEnumToMap(&PyvtkDistributedDataFilter_BoundaryModes_Type);

  o = (PyObject *)&PyvtkDistributedDataFilter_BoundaryModes_Type;
  if (PyDict_SetItemString(d, "BoundaryModes", o) != 0)
  {
    Py_DECREF(o);
  }

  for (int c = 0; c < 3; c++)
  {
    typedef vtkDistributedDataFilter::BoundaryModes cxx_enum_type;

    static const struct { const char *name; cxx_enum_type value; }
      constants[3] = {
        { "ASSIGN_TO_ONE_REGION", vtkDistributedDataFilter::ASSIGN_TO_ONE_REGION },
        { "ASSIGN_TO_ALL_INTERSECTING_REGIONS", vtkDistributedDataFilter::ASSIGN_TO_ALL_INTERSECTING_REGIONS },
        { "SPLIT_BOUNDARY_CELLS", vtkDistributedDataFilter::SPLIT_BOUNDARY_CELLS },
      };

    o = PyvtkDistributedDataFilter_BoundaryModes_FromEnum(constants[c].value);
    if (o)
    {
      PyDict_SetItemString(d, constants[c].name, o);
      Py_DECREF(o);
    }
  }

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkDistributedDataFilter(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkDistributedDataFilter_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkDistributedDataFilter", o) != 0)
  {
    Py_DECREF(o);
  }

}

