// python wrapper for vtkPWindBladeReader
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkPWindBladeReader.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkPWindBladeReader(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkPWindBladeReader_ClassNew(); }

#ifndef DECLARED_PyvtkWindBladeReader_ClassNew
extern "C" { PyObject *PyvtkWindBladeReader_ClassNew(); }
#define DECLARED_PyvtkWindBladeReader_ClassNew
#endif

static const char *PyvtkPWindBladeReader_Doc =
  "vtkPWindBladeReader - class for reading WindBlade data files\n\n"
  "Superclass: vtkWindBladeReader\n\n"
  "vtkPWindBladeReader is a source object that reads WindBlade files\n"
  "which are block binary files with tags before and after each block\n"
  "giving the number of bytes within the block.  The number of data\n"
  "variables dumped varies.  There are 3 output ports with the first\n"
  "being a structured grid with irregular spacing in the Z dimension.\n"
  "The second is an unstructured grid only read on on process 0 and used\n"
  "to represent the blade.  The third is also a structured grid with\n"
  "irregular spacing on the Z dimension.  Only the first and second\n"
  "output ports have time dependent data. Parallel version of\n"
  "vtkWindBladeReader.h\n\n";


static PyObject *
PyvtkPWindBladeReader_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkPWindBladeReader::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPWindBladeReader_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPWindBladeReader *op = static_cast<vtkPWindBladeReader *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkPWindBladeReader::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPWindBladeReader_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkPWindBladeReader *tempr = vtkPWindBladeReader::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPWindBladeReader_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPWindBladeReader *op = static_cast<vtkPWindBladeReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkPWindBladeReader *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkPWindBladeReader::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}

static PyMethodDef PyvtkPWindBladeReader_Methods[] = {
  {"IsTypeOf", PyvtkPWindBladeReader_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkPWindBladeReader_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkPWindBladeReader_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkPWindBladeReader\nC++: static vtkPWindBladeReader *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkPWindBladeReader_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkPWindBladeReader\nC++: vtkPWindBladeReader *NewInstance()\n\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkPWindBladeReader_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkIOMPIParallelPython.vtkPWindBladeReader", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  nullptr, // tp_print
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkPWindBladeReader_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkPWindBladeReader_StaticNew()
{
  return vtkPWindBladeReader::New();
}

PyObject *PyvtkPWindBladeReader_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkPWindBladeReader_Type, PyvtkPWindBladeReader_Methods,
    "vtkPWindBladeReader",
 &PyvtkPWindBladeReader_StaticNew);

  PyTypeObject *pytype = &PyvtkPWindBladeReader_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkWindBladeReader_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkPWindBladeReader(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkPWindBladeReader_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkPWindBladeReader", o) != 0)
  {
    Py_DECREF(o);
  }

}

